====================
pyscaffoldext-travis
====================

Travis CI configuration for `PyScaffold`_

Contents
========

.. toctree::
   :maxdepth: 2

   Pyscaffold Travis CI Extension <readme>
   Module Reference <api/modules>
   License <license>
   Authors <authors>
   Changelog <changelog>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _PyScaffold: https://pyscaffold.org
